diff --git a/Documentation/ProjectFile/properties/property/Exponential/c_Exponential.md b/Documentation/ProjectFile/properties/property/Exponential/c_Exponential.md
index 4a437f4d947bf3c012ee5cba7d32a33363878a51..509ce518349777577884e27897181966a1b43fa0 100644
--- a/Documentation/ProjectFile/properties/property/Exponential/c_Exponential.md
+++ b/Documentation/ProjectFile/properties/property/Exponential/c_Exponential.md
@@ -1,7 +1 @@
-Definition of a exponential property:
-\f$y(x) = y_{\textrm{offset}} + y_{\textrm{ref}} \exp(m (x - x_{\textrm{ref}}))\f$
-where
- - \f$y_{\textrm{ref}}\f$ is a reference value, for instance reference viscosity
- - \f$m\f$ is a factor influencing the exponent of the exponential relationship
- - \f$x_{\textrm{ref}}\f$ is a reference condition, for instance reference
-   temperature
+\copydoc MaterialPropertyLib::Exponential
diff --git a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_factor.md b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_factor.md
index 5d84454ec470fc7c5cdf4238807abfba1164b3f3..253e9241bfa74b7c6da03521d9c68fe15df1a9b8 100644
--- a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_factor.md
+++ b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_factor.md
@@ -1 +1 @@
-\f$f\f$ is a factor included in the exponent of the exponential relationship.
+\copydoc MaterialPropertyLib::ExponentData::factor
diff --git a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_reference_condition.md b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_reference_condition.md
index d2ce5c3ff3dd5d85375f5663dfbb44866208f521..dfca0f86371877711a875ba9f45f5715ca5f278d 100644
--- a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_reference_condition.md
+++ b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_reference_condition.md
@@ -1 +1 @@
-A numeric value for the reference condition \f$x_{\textrm{ref}}\f$.
+\copydoc MaterialPropertyLib::ExponentData::reference_condition
diff --git a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_variable_name.md b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_variable_name.md
index f865903e1da33af6d574f07da94cb8494259153e..96f349b9e46d78750fead8f6036362d258a61ff5 100644
--- a/Documentation/ProjectFile/properties/property/Exponential/exponent/t_variable_name.md
+++ b/Documentation/ProjectFile/properties/property/Exponential/exponent/t_variable_name.md
@@ -1 +1 @@
-The variable type the exponential relationship depends on.
+The independent variable name the exponential relationship depends on.
diff --git a/MaterialLib/MPL/Properties/Exponential.h b/MaterialLib/MPL/Properties/Exponential.h
index 6c8148b7cfaec443dcf5aea36278051a0da5a914..15213ca5d4a75a60cffa207df242245f5dcb1c4c 100644
--- a/MaterialLib/MPL/Properties/Exponential.h
+++ b/MaterialLib/MPL/Properties/Exponential.h
@@ -17,15 +17,26 @@ namespace MaterialPropertyLib
 struct ExponentData
 {
     Variable type;
-    VariableType reference_condition;
-    VariableType factor;
+    VariableType
+        reference_condition;  ///< a reference condition value of independent
+                              ///< variable, for instance reference temperature.
+    VariableType factor;      ///< a dimensionless exponent.
 };
 
 /// The exponential property class. This property calculates the exponential
 /// relationship \f$ \alpha(\beta) = \alpha_{\mathrm{offset}} +
 /// \alpha_{\mathrm{ref}} \cdot \exp (-s (\beta - \beta_{\mathrm{ref}})\f$.
 /// The current implementation accepts only the double datatype defined in
 /// PropertyDataType.
 class Exponential final : public Property
 {
 public:
@@ -58,6 +69,6 @@ public:
 
 private:
     ExponentData const exponent_data_;
-    double const offset_;  //< additive offset in units of the property.
+    double const offset_;  ///< additive offset in units of the property.
 };
 }  // namespace MaterialPropertyLib
@@ -17,15 +17,26 @@ namespace MaterialPropertyLib
 };
 
-/// The exponential property class. This property calculates the exponential
-/// relationship \f$ \alpha(\beta) = \alpha_{\mathrm{offset}} +
-/// \alpha_{\mathrm{ref}} \cdot \exp (-s (\beta - \beta_{\mathrm{ref}})\f$.
-/// The current implementation accepts only the double datatype defined in
-/// PropertyDataType.
+/// An exponential property.
+///
+/// This property calculates the exponential relationship \f$ \alpha(\beta) =
+/// \alpha_{\mathrm{offset}} + \alpha_{\mathrm{ref}} \cdot \exp (m (\beta -
+/// \beta_{\mathrm{ref}})\f$, where:
+///  - \f$\alpha_{\mathrm{ref}}\f$ is a reference value, for instance reference
+///    viscosity,
+///  - \f$\alpha_{\mathrm{offset}}\f$ is additive offset in units of the
+///    property,
+///  - \f$m\f$ is a dimensionless exponent,
+///  - \f$\beta_{\mathrm{ref}}\f$ is a reference condition value of independent
+///  variable, for instance reference temperature.
+///
+/// The current implementation accepts only the scalar independent variables.
 class Exponential final : public Property
 {